.. currentmodule:: pdcast

.. _timedelta_types:

Timedelta
=========

Generic
-------

.. _timedelta_type:

.. autoclass:: TimedeltaType

Pandas
------

.. _pandas_timedelta_type:

.. autoclass:: PandasTimedeltaType

Python
------

.. _python_timedelta_type:

.. autoclass:: PythonTimedeltaType

Numpy
-----

.. _numpy_timedelta64_type:

.. autoclass:: NumpyTimedelta64Type
